@@ -66,9 +66,9 @@ class MyForm(QtGui.QMainWindow):
 		"""Send message using defined method (GV, SMS, etc)"""
 		if method == 0: # SIM
 			if self.flashSMS:
-				os.system('/usr/bin/smssend -f -s -n ' + self.number + ' -m "' + self.message + '"')
+				os.system('sudo /usr/bin/smssend -f -s -n ' + self.number + ' -m "' + self.message + '"')
 			else:
-				os.system('sudo /opt/smsbomb/smsMsg.py ' + self.number + ' "' + self.message + '"')
+				os.system('sudo /usr/bin/smssend -s -n ' + self.number + ' -m "' + self.message + '"')
 		elif method == 1: # Google Voice
 			# Import to use proper python sending technique
 			os.system('dbus-send --dest=org.QGVDial.TextServer --session --print-reply /org/QGVDial/TextServer org.QGVDial.TextServer.Text array:string:"' + self.number + '" string:"' + self.message + '"')
